@@ -118,6 +118,8 @@ char *aliaslist[] =
 	"char-major-10-175 agpgart",    /* /dev/agpgart GART AGP mapping access */
 	"char-major-10-184 microcode",	/* Tigran Aivazian <tigran@veritas.com> */
 
+	"char-major-13 input",
+	"char-major-13-32 mousedev",
 	"char-major-14 soundcore",
 	"char-major-19 cyclades",
 	"char-major-20 cyclades",
@@ -141,6 +143,7 @@ char *aliaslist[] =
 	"char-major-108 ppp_generic",
 	"char-major-109 lvm-mod",
 	"char-major-161 ircomm-tty",
+	"char-major-171 raw1394",
 	"char-major-200 vxspec",
 
 	"dos msdos",
@@ -150,8 +153,9 @@ char *aliaslist[] =
 	"iso9660 isofs",
 	"md-personality-1 linear",
 	"md-personality-2 raid0",
-        "md-personality-3 raid1",
-        "md-personality-4 raid5",
+	"md-personality-3 raid1",
+	"md-personality-4 raid5",
+	"md-personality-7 multipath",
 
 	"net-pf-1 unix",	/* PF_UNIX	1  Unix domain sockets */
 	"net-pf-2 ipv4",	/* PF_INET	2  Internet IP Protocol */
@@ -200,7 +204,7 @@ char *aliaslist[] =
 #ifndef __sparc__
 	"parport_lowlevel parport_pc",
 #else
-        "parport_lowlevel parport_ax",
+	"parport_lowlevel parport_ax",
 #endif
 
 	"usbdevfs usbcore",
